'''
## This file is autogenerated from macrosynergy setup.py.

It contains version information for the macrosynergy package.

short_version: 1.2.1

version: 1.2.1

full_version: 1.2.1

git_revision: 233ffc7374ac5b508c5b09a33f2d2d20ff299ca7

release: True

'''
short_version: str = '1.2.1'
version: str = '1.2.1'
full_version: str = '1.2.1'
git_revision: str = '233ffc7374ac5b508c5b09a33f2d2d20ff299ca7'
release: bool = True
if not release:
    version = full_version
